==> struts-6.8.0-src.zip: struts-6.8.0/src/apps/showcase/src/test/java/it/org/apache/struts2/showcase/DispatcherResultTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package it.org.apache.struts2.showcase;

import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.DomElement;
import com.gargoylesoftware.htmlunit.html.HtmlPage;
import org.junit.Assert;
import org.junit.Test;

public class DispatcherResultTest {

    @Test
    public void testDispatchingToJSP() throws Exception {
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(ParameterUtils.getBaseUrl() + "/dispatcher/dispatch.action");

            DomElement div = page.getElementById("dispatcher-result");
            Assert.assertEquals("This page is a result of \"dispatching\" to it from an action", div.asNormalizedText());
        }
    }

    @Test
    public void testDispatchingToAction() throws Exception {
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(ParameterUtils.getBaseUrl() + "/dispatcher/forward.action");

            DomElement div = page.getElementById("dispatcher-result");
            Assert.assertEquals("This page is a result of \"dispatching\" to it from an action", div.asNormalizedText());
        }
    }

}

==> struts-7.1.1-src.zip: struts-7.1.1/src/apps/showcase/src/test/java/it/org/apache/struts2/showcase/DispatcherResultTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package it.org.apache.struts2.showcase;

import org.htmlunit.WebClient;
import org.htmlunit.html.DomElement;
import org.htmlunit.html.HtmlPage;
import org.junit.Assert;
import org.junit.Test;

public class DispatcherResultTest {

    @Test
    public void testDispatchingToJSP() throws Exception {
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(ParameterUtils.getBaseUrl() + "/dispatcher/dispatch.action");

            DomElement div = page.getElementById("dispatcher-result");
            Assert.assertEquals("This page is a result of \"dispatching\" to it from an action", div.asNormalizedText());
        }
    }

    @Test
    public void testDispatchingToAction() throws Exception {
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(ParameterUtils.getBaseUrl() + "/dispatcher/forward.action");

            DomElement div = page.getElementById("dispatcher-result");
            Assert.assertEquals("This page is a result of \"dispatching\" to it from an action", div.asNormalizedText());
        }
    }

}
